Class: PostFinanceCheckout::CountryStateService

Inherits:
Object
  • Object
show all
Defined in:
lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CountryStateService



24
25
26
# File 'lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb', line 24

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



22
23
24
# File 'lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb', line 22

def api_client
  @api_client
end

Instance Method Details

#all(opts = {}) ⇒ Array<RestCountryState>

All This operation returns all states of all countries.



32
33
34
35
# File 'lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb', line 32

def all(opts = {})
  data, _status_code, _headers = all_with_http_info(opts)
  return data
end

#all_with_http_info(opts = {}) ⇒ Array<(Array<RestCountryState>, Fixnum, Hash)>



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb', line 42

def all_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CountryStateService.all ..."
  end
  # resource path
  local_var_path = "/country-state/all".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Array<RestCountryState>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CountryStateService#all\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#country(code, opts = {}) ⇒ Array<RestCountryState>

Find by Country This operation returns all states for a given country.



91
92
93
94
# File 'lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb', line 91

def country(code, opts = {})
  data, _status_code, _headers = country_with_http_info(code, opts)
  return data
end

#country_with_http_info(code, opts = {}) ⇒ Array<(Array<RestCountryState>, Fixnum, Hash)>



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/postfinancecheckout-ruby-sdk/api/country_state_service_api.rb', line 102

def country_with_http_info(code, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CountryStateService.country ..."
  end
  # verify the required parameter 'code' is set
  fail ArgumentError, "Missing the required parameter 'code' when calling CountryStateService.country" if code.nil?
  # resource path
  local_var_path = "/country-state/country".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'code'] = code

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Array<RestCountryState>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CountryStateService#country\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end