Class: PostFinanceCheckout::PaymentConnectorConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentConnectorConfiguration

Initializes the object



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'applicableForTransactionProcessing')
    self.applicable_for_transaction_processing = attributes[:'applicableForTransactionProcessing']
  end

  if attributes.has_key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.has_key?(:'connector')
    self.connector = attributes[:'connector']
  end

  if attributes.has_key?(:'enabledSalesChannels')
    if (value = attributes[:'enabledSalesChannels']).is_a?(Array)
      self.enabled_sales_channels = value
    end
  end

  if attributes.has_key?(:'enabledSpaceViews')
    if (value = attributes[:'enabledSpaceViews']).is_a?(Array)
      self.enabled_space_views = value
    end
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'linkedSpaceId')
    self.linked_space_id = attributes[:'linkedSpaceId']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'paymentMethodConfiguration')
    self.payment_method_configuration = attributes[:'paymentMethodConfiguration']
  end

  if attributes.has_key?(:'plannedPurgeDate')
    self.planned_purge_date = attributes[:'plannedPurgeDate']
  end

  if attributes.has_key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.has_key?(:'processorConfiguration')
    self.processor_configuration = attributes[:'processorConfiguration']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#applicable_for_transaction_processingObject

This property indicates if the connector is currently used for processing transactions. In case either the payment method configuration or the processor configuration is not active the connector will not be used even though the connector state is active.



24
25
26
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 24

def applicable_for_transaction_processing
  @applicable_for_transaction_processing
end

#conditionsObject

If a transaction meet all selected conditions the connector configuration will be used to process the transaction otherwise the next connector configuration in line will be chosen according to the priorities.



27
28
29
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 27

def conditions
  @conditions
end

#connectorObject

Returns the value of attribute connector.



30
31
32
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 30

def connector
  @connector
end

#enabled_sales_channelsObject

Defines the sales channels the connector configuration is enabled for. In case the set is empty, the connector configuration is enabled for all sales channels.



33
34
35
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 33

def enabled_sales_channels
  @enabled_sales_channels
end

#enabled_space_viewsObject

The connector configuration is only enabled for the selected space views. In case the set is empty the connector configuration is enabled for all space views.



36
37
38
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 36

def enabled_space_views
  @enabled_space_views
end

#idObject

A unique identifier for the object.



39
40
41
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 39

def id
  @id
end

#linked_space_idObject

The ID of the space this object belongs to.



42
43
44
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 42

def linked_space_id
  @linked_space_id
end

#nameObject

The connector configuration name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.



45
46
47
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 45

def name
  @name
end

#payment_method_configurationObject

Returns the value of attribute payment_method_configuration.



48
49
50
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 48

def payment_method_configuration
  @payment_method_configuration
end

#planned_purge_dateObject

The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.



51
52
53
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 51

def planned_purge_date
  @planned_purge_date
end

#priorityObject

The priority will define the order of choice of the connector configurations. The lower the value, the higher the priority is going to be. This value can also be a negative number in case you are adding a new configuration that you want to have a high priority and you dont want to change the priority of all the other configurations.



54
55
56
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 54

def priority
  @priority
end

#processor_configurationObject

Returns the value of attribute processor_configuration.



57
58
59
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 57

def processor_configuration
  @processor_configuration
end

#stateObject

The object’s current state.



60
61
62
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 60

def state
  @state
end

#versionObject

The version is used for optimistic locking and incremented whenever the object is updated.



63
64
65
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 63

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 66

def self.attribute_map
  {
    :'applicable_for_transaction_processing' => :'applicableForTransactionProcessing',
    :'conditions' => :'conditions',
    :'connector' => :'connector',
    :'enabled_sales_channels' => :'enabledSalesChannels',
    :'enabled_space_views' => :'enabledSpaceViews',
    :'id' => :'id',
    :'linked_space_id' => :'linkedSpaceId',
    :'name' => :'name',
    :'payment_method_configuration' => :'paymentMethodConfiguration',
    :'planned_purge_date' => :'plannedPurgeDate',
    :'priority' => :'priority',
    :'processor_configuration' => :'processorConfiguration',
    :'state' => :'state',
    :'version' => :'version'
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 86

def self.swagger_types
  {
    :'applicable_for_transaction_processing' => :'BOOLEAN',
    :'conditions' => :'Array<Integer>',
    :'connector' => :'Integer',
    :'enabled_sales_channels' => :'Array<SalesChannel>',
    :'enabled_space_views' => :'Array<Integer>',
    :'id' => :'Integer',
    :'linked_space_id' => :'Integer',
    :'name' => :'String',
    :'payment_method_configuration' => :'PaymentMethodConfiguration',
    :'planned_purge_date' => :'DateTime',
    :'priority' => :'Integer',
    :'processor_configuration' => :'PaymentProcessorConfiguration',
    :'state' => :'CreationEntityState',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applicable_for_transaction_processing == o.applicable_for_transaction_processing &&
      conditions == o.conditions &&
      connector == o.connector &&
      enabled_sales_channels == o.enabled_sales_channels &&
      enabled_space_views == o.enabled_space_views &&
      id == o.id &&
      linked_space_id == o.linked_space_id &&
      name == o.name &&
      payment_method_configuration == o.payment_method_configuration &&
      planned_purge_date == o.planned_purge_date &&
      priority == o.priority &&
      processor_configuration == o.processor_configuration &&
      state == o.state &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 261

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = PostFinanceCheckout.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 327

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 240

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


227
228
229
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 227

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



233
234
235
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 233

def hash
  [applicable_for_transaction_processing, conditions, connector, enabled_sales_channels, enabled_space_views, id, linked_space_id, name, payment_method_configuration, planned_purge_date, priority, processor_configuration, state, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



178
179
180
181
182
183
184
185
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 178

def list_invalid_properties
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



307
308
309
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 307

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



301
302
303
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 301

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



189
190
191
192
# File 'lib/postfinancecheckout-ruby-sdk/models/payment_connector_configuration.rb', line 189

def valid?
  return false if !@name.nil? && @name.to_s.length > 100
  true
end