Class: PostFinanceCheckout::PaymentTerminalTransactionSummaryService

Inherits:
Object
  • Object
show all
Defined in:
lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PaymentTerminalTransactionSummaryService



24
25
26
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 24

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



22
23
24
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 22

def api_client
  @api_client
end

Instance Method Details

#count(space_id, opts = {}) ⇒ Integer

Count Counts the number of items in the database as restricted by the given filter.

Options Hash (opts):

  • :filter (EntityQueryFilter)

    The filter which restricts the entities which are used to calculate the count.



34
35
36
37
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 34

def count(space_id, opts = {})
  data, _status_code, _headers = count_with_http_info(space_id, opts)
  return data
end

#count_with_http_info(space_id, opts = {}) ⇒ Array<(Integer, Fixnum, Hash)>

Returns Integer data, response status code and response headers.

Options Hash (opts):

  • :filter (EntityQueryFilter)

    The filter which restricts the entities which are used to calculate the count.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 46

def count_with_http_info(space_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentTerminalTransactionSummaryService.count ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling PaymentTerminalTransactionSummaryService.count" if space_id.nil?
  # resource path
  local_var_path = "/payment-terminal-transaction-summary/count".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'filter'])
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Integer')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentTerminalTransactionSummaryService#count\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#fetch_receipt(space_id, request, opts = {}) ⇒ RenderedTerminalTransactionSummary

Fetch Receipt Returns the terminal receipt corresponding to the specified transaction summary id.



99
100
101
102
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 99

def fetch_receipt(space_id, request, opts = {})
  data, _status_code, _headers = fetch_receipt_with_http_info(space_id, request, opts)
  return data
end

#fetch_receipt_with_http_info(space_id, request, opts = {}) ⇒ Array<(RenderedTerminalTransactionSummary, Fixnum, Hash)>



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 111

def fetch_receipt_with_http_info(space_id, request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentTerminalTransactionSummaryService.fetch_receipt ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling PaymentTerminalTransactionSummaryService.fetch_receipt" if space_id.nil?
  # verify the required parameter 'request' is set
  fail ArgumentError, "Missing the required parameter 'request' when calling PaymentTerminalTransactionSummaryService.fetch_receipt" if request.nil?
  # resource path
  local_var_path = "/payment-terminal-transaction-summary/fetch-receipt".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'RenderedTerminalTransactionSummary')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentTerminalTransactionSummaryService#fetch_receipt\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(space_id, id, opts = {}) ⇒ PaymentTerminalTransactionSummary

Read Reads the entity with the given ‘id’ and returns it.



166
167
168
169
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 166

def read(space_id, id, opts = {})
  data, _status_code, _headers = read_with_http_info(space_id, id, opts)
  return data
end

#read_with_http_info(space_id, id, opts = {}) ⇒ Array<(PaymentTerminalTransactionSummary, Fixnum, Hash)>



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 178

def read_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentTerminalTransactionSummaryService.read ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling PaymentTerminalTransactionSummaryService.read" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling PaymentTerminalTransactionSummaryService.read" if id.nil?
  # resource path
  local_var_path = "/payment-terminal-transaction-summary/read".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'PaymentTerminalTransactionSummary')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentTerminalTransactionSummaryService#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search(space_id, query, opts = {}) ⇒ Array<PaymentTerminalTransactionSummary>

Search Searches for the entities as specified by the given query.



234
235
236
237
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 234

def search(space_id, query, opts = {})
  data, _status_code, _headers = search_with_http_info(space_id, query, opts)
  return data
end

#search_with_http_info(space_id, query, opts = {}) ⇒ Array<(Array<PaymentTerminalTransactionSummary>, Fixnum, Hash)>



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/postfinancecheckout-ruby-sdk/api/payment_terminal_transaction_summary_service_api.rb', line 246

def search_with_http_info(space_id, query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentTerminalTransactionSummaryService.search ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling PaymentTerminalTransactionSummaryService.search" if space_id.nil?
  # verify the required parameter 'query' is set
  fail ArgumentError, "Missing the required parameter 'query' when calling PaymentTerminalTransactionSummaryService.search" if query.nil?
  # resource path
  local_var_path = "/payment-terminal-transaction-summary/search".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(query)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Array<PaymentTerminalTransactionSummary>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentTerminalTransactionSummaryService#search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end