Class: PostFinanceCheckout::TokenVersionService

Inherits:
Object
  • Object
show all
Defined in:
lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TokenVersionService



24
25
26
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 24

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



22
23
24
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 22

def api_client
  @api_client
end

Instance Method Details

#active_version(space_id, id, opts = {}) ⇒ TokenVersion

Active Version Returns the token version which is currently active given by the token id. In case no token version is active the method will return null.



34
35
36
37
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 34

def active_version(space_id, id, opts = {})
  data, _status_code, _headers = active_version_with_http_info(space_id, id, opts)
  return data
end

#active_version_with_http_info(space_id, id, opts = {}) ⇒ Array<(TokenVersion, Fixnum, Hash)>



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 46

def active_version_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TokenVersionService.active_version ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TokenVersionService.active_version" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TokenVersionService.active_version" if id.nil?
  # resource path
  local_var_path = "/token-version/active-version".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'TokenVersion')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TokenVersionService#active_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#count(space_id, opts = {}) ⇒ Integer

Count Counts the number of items in the database as restricted by the given filter.

Options Hash (opts):

  • :filter (EntityQueryFilter)

    The filter which restricts the entities which are used to calculate the count.



102
103
104
105
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 102

def count(space_id, opts = {})
  data, _status_code, _headers = count_with_http_info(space_id, opts)
  return data
end

#count_with_http_info(space_id, opts = {}) ⇒ Array<(Integer, Fixnum, Hash)>

Returns Integer data, response status code and response headers.

Options Hash (opts):

  • :filter (EntityQueryFilter)

    The filter which restricts the entities which are used to calculate the count.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 114

def count_with_http_info(space_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TokenVersionService.count ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TokenVersionService.count" if space_id.nil?
  # resource path
  local_var_path = "/token-version/count".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'filter'])
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Integer')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TokenVersionService#count\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(space_id, id, opts = {}) ⇒ TokenVersion

Read Reads the entity with the given ‘id’ and returns it.



167
168
169
170
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 167

def read(space_id, id, opts = {})
  data, _status_code, _headers = read_with_http_info(space_id, id, opts)
  return data
end

#read_with_http_info(space_id, id, opts = {}) ⇒ Array<(TokenVersion, Fixnum, Hash)>



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 179

def read_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TokenVersionService.read ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TokenVersionService.read" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TokenVersionService.read" if id.nil?
  # resource path
  local_var_path = "/token-version/read".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'TokenVersion')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TokenVersionService#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search(space_id, query, opts = {}) ⇒ Array<TokenVersion>

Search Searches for the entities as specified by the given query.



235
236
237
238
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 235

def search(space_id, query, opts = {})
  data, _status_code, _headers = search_with_http_info(space_id, query, opts)
  return data
end

#search_with_http_info(space_id, query, opts = {}) ⇒ Array<(Array<TokenVersion>, Fixnum, Hash)>



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/postfinancecheckout-ruby-sdk/api/token_version_service_api.rb', line 247

def search_with_http_info(space_id, query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TokenVersionService.search ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TokenVersionService.search" if space_id.nil?
  # verify the required parameter 'query' is set
  fail ArgumentError, "Missing the required parameter 'query' when calling TokenVersionService.search" if query.nil?
  # resource path
  local_var_path = "/token-version/search".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(query)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Array<TokenVersion>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TokenVersionService#search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end