Class: PostFinanceCheckout::TransactionIframeService
- Inherits:
-
Object
- Object
- PostFinanceCheckout::TransactionIframeService
- Defined in:
- lib/postfinancecheckout-ruby-sdk/api/transaction_iframe_service_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ TransactionIframeService
constructor
A new instance of TransactionIframeService.
-
#javascript_url(space_id, id, opts = {}) ⇒ String
Build JavaScript URL This operation creates the URL which can be used to embed the JavaScript for handling the iFrame checkout flow.
-
#javascript_url_with_http_info(space_id, id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
String data, response status code and response headers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TransactionIframeService
24 25 26 |
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_iframe_service_api.rb', line 24 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
22 23 24 |
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_iframe_service_api.rb', line 22 def api_client @api_client end |
Instance Method Details
#javascript_url(space_id, id, opts = {}) ⇒ String
Build JavaScript URL This operation creates the URL which can be used to embed the JavaScript for handling the iFrame checkout flow.
34 35 36 37 |
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_iframe_service_api.rb', line 34 def javascript_url(space_id, id, opts = {}) data, _status_code, _headers = javascript_url_with_http_info(space_id, id, opts) return data end |
#javascript_url_with_http_info(space_id, id, opts = {}) ⇒ Array<(String, Fixnum, Hash)>
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_iframe_service_api.rb', line 46 def javascript_url_with_http_info(space_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TransactionIframeService.javascript_url ..." end # verify the required parameter 'space_id' is set fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionIframeService.javascript_url" if space_id.nil? # verify the required parameter 'id' is set fail ArgumentError, "Missing the required parameter 'id' when calling TransactionIframeService.javascript_url" if id.nil? # resource path local_var_path = "/transaction-iframe/javascript-url".sub('{format}','json') # query parameters query_params = {} query_params[:'spaceId'] = space_id query_params[:'id'] = id # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json', 'text/plain;charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # connection timeout timeout = @api_client.get_connection_timeout() # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :timeout => timeout, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: TransactionIframeService#javascript_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |