Class: PostFinanceCheckout::TransactionInvoiceService

Inherits:
Object
  • Object
show all
Defined in:
lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TransactionInvoiceService



24
25
26
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 24

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



22
23
24
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 22

def api_client
  @api_client
end

Instance Method Details

#count(space_id, opts = {}) ⇒ Integer

Count Counts the number of items in the database as restricted by the given filter.

Options Hash (opts):

  • :filter (EntityQueryFilter)

    The filter which restricts the entities which are used to calculate the count.



34
35
36
37
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 34

def count(space_id, opts = {})
  data, _status_code, _headers = count_with_http_info(space_id, opts)
  return data
end

#count_with_http_info(space_id, opts = {}) ⇒ Array<(Integer, Fixnum, Hash)>

Returns Integer data, response status code and response headers.

Options Hash (opts):

  • :filter (EntityQueryFilter)

    The filter which restricts the entities which are used to calculate the count.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 46

def count_with_http_info(space_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.count ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.count" if space_id.nil?
  # resource path
  local_var_path = "/transaction-invoice/count".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'filter'])
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Integer')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#count\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_invoice_document(space_id, id, opts = {}) ⇒ RenderedDocument

getInvoiceDocument Returns the PDF document for the transaction invoice with given id.



99
100
101
102
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 99

def get_invoice_document(space_id, id, opts = {})
  data, _status_code, _headers = get_invoice_document_with_http_info(space_id, id, opts)
  return data
end

#get_invoice_document_with_http_info(space_id, id, opts = {}) ⇒ Array<(RenderedDocument, Fixnum, Hash)>



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 111

def get_invoice_document_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.get_invoice_document ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.get_invoice_document" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.get_invoice_document" if id.nil?
  # resource path
  local_var_path = "/transaction-invoice/getInvoiceDocument".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'RenderedDocument')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#get_invoice_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_invoice_document_with_target_media_type(space_id, id, target_media_type_id, opts = {}) ⇒ RenderedDocument

getInvoiceDocumentWithTargetMediaType Returns the PDF document for the transaction invoice with given id and target media type id.



168
169
170
171
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 168

def get_invoice_document_with_target_media_type(space_id, id, target_media_type_id, opts = {})
  data, _status_code, _headers = get_invoice_document_with_target_media_type_with_http_info(space_id, id, target_media_type_id, opts)
  return data
end

#get_invoice_document_with_target_media_type_with_http_info(space_id, id, target_media_type_id, opts = {}) ⇒ Array<(RenderedDocument, Fixnum, Hash)>



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 181

def get_invoice_document_with_target_media_type_with_http_info(space_id, id, target_media_type_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.get_invoice_document_with_target_media_type ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.get_invoice_document_with_target_media_type" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.get_invoice_document_with_target_media_type" if id.nil?
  # verify the required parameter 'target_media_type_id' is set
  fail ArgumentError, "Missing the required parameter 'target_media_type_id' when calling TransactionInvoiceService.get_invoice_document_with_target_media_type" if target_media_type_id.nil?
  # resource path
  local_var_path = "/transaction-invoice/getInvoiceDocumentWithTargetMediaType".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id
  query_params[:'targetMediaTypeId'] = target_media_type_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'RenderedDocument')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#get_invoice_document_with_target_media_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#is_replacement_possible(space_id, id, opts = {}) ⇒ BOOLEAN

isReplacementPossible Returns whether the transaction invoice with the given id can be replaced.



240
241
242
243
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 240

def is_replacement_possible(space_id, id, opts = {})
  data, _status_code, _headers = is_replacement_possible_with_http_info(space_id, id, opts)
  return data
end

#is_replacement_possible_with_http_info(space_id, id, opts = {}) ⇒ Array<(BOOLEAN, Fixnum, Hash)>



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 252

def is_replacement_possible_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.is_replacement_possible ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.is_replacement_possible" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.is_replacement_possible" if id.nil?
  # resource path
  local_var_path = "/transaction-invoice/isReplacementPossible".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'BOOLEAN')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#is_replacement_possible\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#mark_as_derecognized(space_id, id, opts = {}) ⇒ TransactionInvoice

Mark as Derecognized Marks the transaction invoice with the given id as derecognized.



308
309
310
311
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 308

def mark_as_derecognized(space_id, id, opts = {})
  data, _status_code, _headers = mark_as_derecognized_with_http_info(space_id, id, opts)
  return data
end

#mark_as_derecognized_with_http_info(space_id, id, opts = {}) ⇒ Array<(TransactionInvoice, Fixnum, Hash)>



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 320

def mark_as_derecognized_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.mark_as_derecognized ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.mark_as_derecognized" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.mark_as_derecognized" if id.nil?
  # resource path
  local_var_path = "/transaction-invoice/markAsDerecognized".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'TransactionInvoice')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#mark_as_derecognized\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#mark_as_paid(space_id, id, opts = {}) ⇒ TransactionInvoice

Mark as Paid Marks the transaction invoice with the given id as paid.



376
377
378
379
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 376

def mark_as_paid(space_id, id, opts = {})
  data, _status_code, _headers = mark_as_paid_with_http_info(space_id, id, opts)
  return data
end

#mark_as_paid_with_http_info(space_id, id, opts = {}) ⇒ Array<(TransactionInvoice, Fixnum, Hash)>



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 388

def mark_as_paid_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.mark_as_paid ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.mark_as_paid" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.mark_as_paid" if id.nil?
  # resource path
  local_var_path = "/transaction-invoice/markAsPaid".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'TransactionInvoice')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#mark_as_paid\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(space_id, id, opts = {}) ⇒ TransactionInvoice

Read Reads the entity with the given ‘id’ and returns it.



444
445
446
447
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 444

def read(space_id, id, opts = {})
  data, _status_code, _headers = read_with_http_info(space_id, id, opts)
  return data
end

#read_with_http_info(space_id, id, opts = {}) ⇒ Array<(TransactionInvoice, Fixnum, Hash)>



456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 456

def read_with_http_info(space_id, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.read ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.read" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.read" if id.nil?
  # resource path
  local_var_path = "/transaction-invoice/read".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['*/*']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'TransactionInvoice')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#replace(space_id, id, replacement, opts = {}) ⇒ TransactionInvoice

replace Replaces the transaction invoice with given id with the replacement and returns the new transaction invoice.



513
514
515
516
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 513

def replace(space_id, id, replacement, opts = {})
  data, _status_code, _headers = replace_with_http_info(space_id, id, replacement, opts)
  return data
end

#replace_with_http_info(space_id, id, replacement, opts = {}) ⇒ Array<(TransactionInvoice, Fixnum, Hash)>



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 526

def replace_with_http_info(space_id, id, replacement, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.replace ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.replace" if space_id.nil?
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling TransactionInvoiceService.replace" if id.nil?
  # verify the required parameter 'replacement' is set
  fail ArgumentError, "Missing the required parameter 'replacement' when calling TransactionInvoiceService.replace" if replacement.nil?
  # resource path
  local_var_path = "/transaction-invoice/replace".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id
  query_params[:'id'] = id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(replacement)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'TransactionInvoice')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#replace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search(space_id, query, opts = {}) ⇒ Array<TransactionInvoice>

Search Searches for the entities as specified by the given query.



584
585
586
587
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 584

def search(space_id, query, opts = {})
  data, _status_code, _headers = search_with_http_info(space_id, query, opts)
  return data
end

#search_with_http_info(space_id, query, opts = {}) ⇒ Array<(Array<TransactionInvoice>, Fixnum, Hash)>



596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
# File 'lib/postfinancecheckout-ruby-sdk/api/transaction_invoice_service_api.rb', line 596

def search_with_http_info(space_id, query, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TransactionInvoiceService.search ..."
  end
  # verify the required parameter 'space_id' is set
  fail ArgumentError, "Missing the required parameter 'space_id' when calling TransactionInvoiceService.search" if space_id.nil?
  # verify the required parameter 'query' is set
  fail ArgumentError, "Missing the required parameter 'query' when calling TransactionInvoiceService.search" if query.nil?
  # resource path
  local_var_path = "/transaction-invoice/search".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'spaceId'] = space_id

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json;charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json;charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}
  
  # connection timeout
  timeout = @api_client.get_connection_timeout()

  # http body (model)
  post_body = @api_client.object_to_http_body(query)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :timeout => timeout,
    :auth_names => auth_names,
    :return_type => 'Array<TransactionInvoice>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionInvoiceService#search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end